==> aliyun-python-sdk-domain-3.0.0.tar.gz: aliyun-python-sdk-domain-3.0.0/aliyunsdkdomain/request/v20180129/SaveTaskForSubmittingDomainRealNameVerificationByIdentityCredentialRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class SaveTaskForSubmittingDomainRealNameVerificationByIdentityCredentialRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Domain', '2018-01-29', 'SaveTaskForSubmittingDomainRealNameVerificationByIdentityCredential')

	def get_IdentityCredentialType(self):
		return self.get_query_params().get('IdentityCredentialType')

	def set_IdentityCredentialType(self,IdentityCredentialType):
		self.add_query_param('IdentityCredentialType',IdentityCredentialType)

	def get_UserClientIp(self):
		return self.get_query_params().get('UserClientIp')

	def set_UserClientIp(self,UserClientIp):
		self.add_query_param('UserClientIp',UserClientIp)

	def get_IdentityCredential(self):
		return self.get_query_params().get('IdentityCredential')

	def set_IdentityCredential(self,IdentityCredential):
		self.add_query_param('IdentityCredential',IdentityCredential)

	def get_DomainNames(self):
		return self.get_query_params().get('DomainNames')

	def set_DomainNames(self,DomainNames):
		for i in range(len(DomainNames)):	
			if DomainNames[i] is not None:
				self.add_query_param('DomainName.' + str(i + 1) , DomainNames[i]);

	def get_Lang(self):
		return self.get_query_params().get('Lang')

	def set_Lang(self,Lang):
		self.add_query_param('Lang',Lang)

	def get_IdentityCredentialNo(self):
		return self.get_query_params().get('IdentityCredentialNo')

	def set_IdentityCredentialNo(self,IdentityCredentialNo):
		self.add_query_param('IdentityCredentialNo',IdentityCredentialNo)

==> aliyun-python-sdk-domain-3.4.0.tar.gz: aliyun-python-sdk-domain-3.4.0/aliyunsdkdomain/request/v20180129/SaveTaskForSubmittingDomainRealNameVerificationByIdentityCredentialRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class SaveTaskForSubmittingDomainRealNameVerificationByIdentityCredentialRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Domain', '2018-01-29', 'SaveTaskForSubmittingDomainRealNameVerificationByIdentityCredential')
		self.set_method('POST')

	def get_IdentityCredentialType(self):
		return self.get_query_params().get('IdentityCredentialType')

	def set_IdentityCredentialType(self,IdentityCredentialType):
		self.add_query_param('IdentityCredentialType',IdentityCredentialType)

	def get_UserClientIp(self):
		return self.get_query_params().get('UserClientIp')

	def set_UserClientIp(self,UserClientIp):
		self.add_query_param('UserClientIp',UserClientIp)

	def get_IdentityCredential(self):
		return self.get_body_params().get('IdentityCredential')

	def set_IdentityCredential(self,IdentityCredential):
		self.add_body_params('IdentityCredential', IdentityCredential)

	def get_DomainNames(self):
		return self.get_query_params().get('DomainNames')

	def set_DomainNames(self,DomainNames):
		for i in range(len(DomainNames)):	
			if DomainNames[i] is not None:
				self.add_query_param('DomainName.' + str(i + 1) , DomainNames[i]);

	def get_Lang(self):
		return self.get_query_params().get('Lang')

	def set_Lang(self,Lang):
		self.add_query_param('Lang',Lang)

	def get_IdentityCredentialNo(self):
		return self.get_query_params().get('IdentityCredentialNo')

	def set_IdentityCredentialNo(self,IdentityCredentialNo):
		self.add_query_param('IdentityCredentialNo',IdentityCredentialNo)
